"""Type stubs for cloudbase_agent core package.

This stub file provides type hints for IDE and static analysis tools.
"""

# Eager imports (always available)
from .base_agent import AgentCallback as AgentCallback
from .base_agent import BaseAgent as BaseAgent
from .base_agent import ToolCallResult as ToolCallResult
from .base_agent import ToolProxy as ToolProxy

__all__: list[str]
