#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Common utility types.

This module defines common utility types used throughout Cloudbase Agent.
"""

from typing import Any, Dict

# Type aliases
JSON = Dict[str, Any]
Headers = Dict[str, str]
Metadata = Dict[str, Any]
AgentState = Dict[str, Any]
